BuilderNotFoundInFactoryException class

Exception that is thrown when a builder is not found in the factory.

Implemented types

Constructors

BuilderNotFoundInFactoryException(String builderKey)
const

Properties

builderKey → String
final
category → Type
category is either the super class or this class.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
key → String
An identifer for the exception. Default to the class's runtimeType.
no setterinherited
name → String
A more user readable exception name than the key. Default to key unless otherwise specified.
no setterinherited
problem → String
Problem statement of the Exception.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity → ExceptionSeverity
Severity can be none, warning or critical.
no setter
solution → String
Solution statement of the Exception.
no setter
text → String
Complete description of the Exception.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
toString function returns the exception's text.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited